@@ -61,7 +61,6 @@ class Driver:
         self._layers = []
         self._width_cm = 10.0
         self._height_cm = 10.0
-
         self._page_ratio = 1.0
 
         self.background(True)
@@ -323,6 +322,9 @@ class Driver:
         width = self._options("width", 680)
         frame = self._options("frame", False)
 
+        self._width_cm = self._options("width_cm", 10)
+        self._height_cm = self._options("height_cm", 10)
+
         if self._projection is None:
             # TODO: select best projection based on bbox
             self._projection = mmap(subpage_map_projection="cylindrical")
@@ -386,8 +388,14 @@ class Driver:
 
         args = [page] + self.macro()
 
-        if self._options("dump_python", False):
-            print(args)
+        dump = self._options("dump_python", False)
+        if dump:
+            m = "from Magics import macro\nmacro.plot({})".format(args)
+            if isinstance(dump, str):
+                with open(dump, "w") as f:
+                    print(m, file=f)
+            else:
+                print(m)
 
         dump = self._options("dump_yaml", False)
         if dump:
